@@ -1,3 +1,5 @@
+from tracardi_dot_notation.dot_accessor import DotAccessor
+
 from tracardi.process_engine.tql.parser import Parser
 from tracardi.process_engine.tql.transformer.expr_transformer import ExprTransformer
 
@@ -10,7 +12,7 @@ class Condition:
         return parser.parse(condition)
 
     @staticmethod
-    def evaluate(condition, data):
+    def evaluate(condition, dot: DotAccessor):
         tree = Condition.parse(condition)
-        return ExprTransformer(data=data).transform(tree)
+        return ExprTransformer(dot=dot).transform(tree)
 
